@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2022 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -23,6 +23,60 @@
 
 namespace FeatherPad {
 
+// Qt6 has changed "QFont::toString()" in a backward incompatible way, so that,
+// if a document is saved by the Qt6 version, the Qt5 version will show wrong fonts.
+// This function circumvents the problem when it's used instead of "QFont::fromString()".
+static inline void fontFromString (QFont &f, const QString &str)
+{
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+    const QChar comma (QLatin1Char (','));
+    QStringList l = str.split (comma);
+    if (l.size() <= 10)
+        f.fromString (str);
+    else
+    {
+        l = l.mid (0, 10);
+        int weight = l.at (4).toInt();
+        switch (weight) {
+        case 100:
+            weight = 0;
+            break;
+        case 200:
+            weight = 12;
+            break;
+        case 300:
+            weight = 25;
+            break;
+        case 400:
+            weight = 50;
+            break;
+        case 500:
+            weight = 57;
+            break;
+        case 600:
+            weight = 63;
+            break;
+        case 700:
+            weight = 75;
+            break;
+        case 800:
+            weight = 81;
+            break;
+        case 900:
+            weight = 87;
+            break;
+        default:
+            weight = 50;
+            break;
+        }
+        l[4] = QString::number (weight);
+        f.fromString (l.join (comma));
+    }
+#else
+    f.fromString (str);
+#endif
+}
+/*************************/
 Config::Config():
     remSize_ (true),
     remPos_ (false),
@@ -63,6 +117,7 @@ Config::Config():
     closeWithLastTab_ (false),
     sharedSearchHistory_ (false),
     disableMenubarAccel_ (false),
+    sysIcons_ (false),
     vLineDistance_ (-80),
     tabPosition_ (0),
     maxSHSize_ (2),
@@ -75,7 +130,7 @@ Config::Config():
     winSize_ (QSize (700, 500)),
     startSize_ (QSize (700, 500)),
     winPos_ (QPoint (0, 0)),
-    splitterPos_ (20), // percentage
+    splitterPos_ (150),
     font_ (QFont ("Monospace")),
     recentOpened_ (false),
     saveLastFilesList_ (false),
@@ -121,7 +176,7 @@ void Config::readConfig()
     if (settings.value ("splitterPos") == "none")
         remSplitterPos_ = false; // true by default
     else
-        splitterPos_ = qMin (qMax (settings.value ("splitterPos", 20).toInt(), 0), 100);
+        splitterPos_ = qMax (settings.value ("splitterPos", 150).toInt(), 0);
 
     prefSize_ = settings.value ("prefSize").toSize();
 
@@ -179,6 +234,9 @@ void Config::readConfig()
     if (settings.value ("disableMenubarAccel").toBool())
         disableMenubarAccel_ = true; // false by default
 
+    if (settings.value ("sysIcons").toBool())
+        sysIcons_ = true; // false by default
+
     settings.endGroup();
 
     /************
@@ -196,7 +254,7 @@ void Config::readConfig()
     {
         QString fontStr = settings.value ("font").toString();
         if (!fontStr.isEmpty())
-            font_.fromString (fontStr);
+            fontFromString (font_, fontStr);
         else
             font_.setPointSize (qMax (QFont().pointSize(), 9));
     }
@@ -275,7 +333,7 @@ void Config::readConfig()
     if (settings.value ("removeTrailingSpaces").toBool())
         removeTrailingSpaces_ = true; // false by default
 
-    recentFilesNumber_ = qBound (0, settings.value ("recentFilesNumber", 10).toInt(), 20);
+    recentFilesNumber_ = qBound (0, settings.value ("recentFilesNumber", 10).toInt(), 50);
     curRecentFilesNumber_ = recentFilesNumber_; // fixed
     recentFiles_ = settings.value ("recentFiles").toStringList();
     recentFiles_.removeAll ("");
@@ -445,6 +503,7 @@ void Config::writeConfig()
     settings.setValue ("closeWithLastTab", closeWithLastTab_);
     settings.setValue ("sharedSearchHistory", sharedSearchHistory_);
     settings.setValue ("disableMenubarAccel", disableMenubarAccel_);
+    settings.setValue ("sysIcons", sysIcons_);
 
     settings.endGroup();
 
