@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2019 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2021 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -135,7 +135,7 @@ public:
         return recentFilesNumber_;
     }
     void setRecentFilesNumber (int number) {
-        recentFilesNumber_ = number;
+        recentFilesNumber_ = qBound (0, number, 50);
     }
     int getCurRecentFilesNumber() const {
         return curRecentFilesNumber_;
@@ -513,6 +513,13 @@ public:
     void setDisableMenubarAccel (bool disable) {
         disableMenubarAccel_ = disable;
     }
+/*************************/
+    bool getSysIcons() const {
+        return sysIcons_;
+    }
+    void setSysIcons (bool sysIcons) {
+        sysIcons_ = sysIcons;
+    }
 /*************************/
     QString getDictPath() const {
         return dictPath_;
@@ -600,7 +607,8 @@ private:
          pastePaths_,
          closeWithLastTab_,
          sharedSearchHistory_,
-         disableMenubarAccel_;
+         disableMenubarAccel_,
+         sysIcons_;
     int vLineDistance_,
         tabPosition_,
         maxSHSize_,
