@@ -144,7 +144,11 @@ void Highlighter::yamlLiteralBlock (const QString &text)
     QRegularExpressionMatch match;
     if (previousBlockState() == codeBlockState) // the literal block may continue
     {
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
         text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
+#else
+        (void)text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
+#endif
         QString startingSpaces = "i" + match.captured();
         if (text == match.captured() // only whitespaces...
             /* ... or the indentation is wider than that of the literal block */
@@ -161,12 +165,30 @@ void Highlighter::yamlLiteralBlock (const QString &text)
     /* the start of a literal block (which is formatted near the end of the main formatting
        because, if it was formatted here, its format might be overridden by that of a value) */
     static const QRegularExpression yamlBlockStartExp ("^(?!#)(?:(?!\\s#).)*\\s+\\K(\\||>)-?\\s*(?=\\s#|$)");
+    static const QRegularExpression yamlKey ("\\s*[^\\s\"\'#][^:,#]*:\\s+");
     int index = text.indexOf (yamlBlockStartExp, 0);
     if (index >= 0)
     {
+        if (text.contains (yamlKey))
+        { // consider the list sign as a space if the block is a value
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+            text.indexOf (QRegularExpression ("^\\s*(-\\s)?\\s*"), 0, &match);
+#else
+            (void)text.indexOf (QRegularExpression ("^\\s*(-\\s)?\\s*"), 0, &match);
+#endif
+        }
+        else
+        {
+            if (text.indexOf (QRegularExpression ("^\\s*-\\s")) == -1)
+                return; // if the block isn't a value, it should be a list
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+            text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
+#else
+            (void)text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
+#endif
+        }
         setCurrentBlockState (codeBlockState);
-        text.indexOf (QRegularExpression ("^\\s*"), 0, &match);
-        data->insertInfo ("i" + match.captured());
+        data->insertInfo ("i" + match.captured().replace ("-", " "));
     }
 }
 /*************************/
@@ -261,6 +283,7 @@ void Highlighter::highlightYamlBlock (const QString &text)
     if (bn >= startCursor.blockNumber() && bn <= endCursor.blockNumber())
     {
         data->setHighlighted();
+        QRegularExpressionMatch match;
         for (const HighlightingRule &rule : qAsConst (highlightingRules))
         {
             if (rule.format != whiteSpaceFormat
@@ -271,7 +294,6 @@ void Highlighter::highlightYamlBlock (const QString &text)
             if (rule.format == commentFormat)
                 continue;
 
-            QRegularExpressionMatch match;
             index = text.indexOf (rule.pattern, 0, &match);
             if (rule.format != whiteSpaceFormat)
             {
