@@ -126,6 +126,7 @@ private slots:
     void restoreDefaultSyntaxColors();
     void changeCurLineHighlight (int value);
     void disableMenubarAccel (int checked);
+    void prefIcon (int checked);
 
 private:
     void closeEvent (QCloseEvent *event);
@@ -141,7 +142,7 @@ private:
 
     Ui::PrefDialog *ui;
     QWidget * parent_;
-    bool darkBg_, showWhiteSpace_, showEndings_, saveUnmodified_, sharedSearchHistory_, selHighlighting_, pastePaths_, disableMenubarAccel_;
+    bool darkBg_, showWhiteSpace_, showEndings_, saveUnmodified_, sharedSearchHistory_, selHighlighting_, pastePaths_, disableMenubarAccel_, sysIcons_;
     int vLineDistance_, darkColValue_, lightColValue_, recentNumber_, textTabSize_, whiteSpaceValue_, curLineHighlight_;
     QHash<QString, QString> shortcuts_, newShortcuts_;
     QString prevtMsg_;
