@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2014-2021 <tsujan2000@gmail.com>
  *
  * FeatherPad is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,7 +17,10 @@
  * @license GPL-3.0+ <https://spdx.org/licenses/GPL-3.0+.html>
  */
 
+#include <QApplication>
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 #include <QX11Info>
+#endif
 #include "x11.h"
 
 #include <X11/Xatom.h>
@@ -29,12 +32,23 @@ namespace FeatherPad {
  *** because Qt does not fetch enough information on X11. ***
  *************************************************************/
 
+static inline Display* getDisplay()
+{
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+    return QX11Info::display();
+#else
+    if (auto x11NativeInterfce = qApp->nativeInterface<QNativeInterface::QX11Application>())
+        return x11NativeInterfce->display();
+    return nullptr;
+#endif
+}
+
 // Get the current virtual desktop.
 long fromDesktop()
 {
     long res = -1;
 
-    Display  *disp = QX11Info::display();
+    Display *disp = getDisplay();
     if (!disp) return res;
 
     Atom actual_type;
@@ -67,7 +81,7 @@ long onWhichDesktop (Window window)
 {
     long res = -1;
 
-    Display *disp = QX11Info::display();
+    Display *disp = getDisplay();
     if (!disp) return res;
 
     Atom wm_desktop = XInternAtom (disp, "_NET_WM_DESKTOP", False);
@@ -100,7 +114,7 @@ long onWhichDesktop (Window window)
 
 bool isWindowShaded (Window window)
 {
-    Display *disp = QX11Info::display();
+    Display *disp = getDisplay();
     if (!disp) return false;
 
     Atom property = XInternAtom (disp, "_NET_WM_STATE", False);
@@ -133,7 +147,7 @@ bool isWindowShaded (Window window)
 /*************************/
 void unshadeWindow (Window window)
 {
-    Display *disp = QX11Info::display();
+    Display *disp = getDisplay();
     if (!disp) return;
 
     Atom atomtype = XInternAtom (disp, "_NET_WM_STATE", False);
